==> jc-1.4.0.tar.gz: java/security/SecureClassLoader.h <==
// public class java.security.SecureClassLoader

// class file dependencies
// @dep_class 26b8d7b7a241db31 java_lang_ClassLoader
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 50a05c4401dcb8be java_security_SecureClassLoader

// header file dependencies
// @dep_header java_lang_ClassLoader

#include "java/lang/ClassLoader.h"

#ifndef _JC_java_security_SecureClassLoader_H_
#define _JC_java_security_SecureClassLoader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_CodeSource$object;
struct _jc_java_security_PermissionCollection$object;
struct _jc_java_util_WeakHashMap$object;

// Typedefs
typedef struct _jc_java_security_SecureClassLoader$sub_refs	_jc_java_security_SecureClassLoader$sub_refs;
typedef struct _jc_java_security_SecureClassLoader$sub_nonrefs	_jc_java_security_SecureClassLoader$sub_nonrefs;
typedef struct _jc_java_security_SecureClassLoader$refs	_jc_java_security_SecureClassLoader$refs;
typedef struct _jc_java_security_SecureClassLoader$nonrefs	_jc_java_security_SecureClassLoader$nonrefs;
typedef struct _jc_java_security_SecureClassLoader$object	_jc_java_security_SecureClassLoader$object;

typedef const struct _jc_java_security_SecureClassLoader$vmethods	_jc_java_security_SecureClassLoader$vmethods;
typedef const struct _jc_java_security_SecureClassLoader$vtable	_jc_java_security_SecureClassLoader$vtable;
typedef const struct _jc_java_security_SecureClassLoader$vtype	_jc_java_security_SecureClassLoader$vtype;

// Constructors
extern void _jc_java_security_SecureClassLoader$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_SecureClassLoader$object *);
extern void _jc_java_security_SecureClassLoader$method$_init$2815ca8f2d550897(_jc_env *, struct _jc_java_security_SecureClassLoader$object *, struct _jc_java_lang_ClassLoader$object *);

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_java_security_SecureClassLoader$method$defineClass$75df0c3a50185132(_jc_env *, struct _jc_java_security_SecureClassLoader$object *, struct _jc_java_lang_String$object *, struct _jc_byte_array *, jint, jint, struct _jc_java_security_CodeSource$object *);
extern struct _jc_java_security_PermissionCollection$object *_jc_java_security_SecureClassLoader$method$getPermissions$448009107719f384(_jc_env *, struct _jc_java_security_SecureClassLoader$object *, struct _jc_java_security_CodeSource$object *);
extern void _jc_java_security_SecureClassLoader$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_SecureClassLoader$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_SecureClassLoader$method_info$defineClass$75df0c3a50185132;
extern _jc_method _jc_java_security_SecureClassLoader$method_info$getPermissions$448009107719f384;
extern _jc_method _jc_java_security_SecureClassLoader$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_security_SecureClassLoader$vmethods {
	struct _jc_java_lang_Class$object	*(*defineClass$75df0c3a50185132)(_jc_env *, struct _jc_java_security_SecureClassLoader$object *, struct _jc_java_lang_String$object *, struct _jc_byte_array *, jint, jint, struct _jc_java_security_CodeSource$object *);
	struct _jc_java_security_PermissionCollection$object	*(*getPermissions$448009107719f384)(_jc_env *, struct _jc_java_security_SecureClassLoader$object *, struct _jc_java_security_CodeSource$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_SecureClassLoader$object *);
};

// Vtable
struct _jc_java_security_SecureClassLoader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_ClassLoader$vmethods	java_lang_ClassLoader;
	_jc_java_security_SecureClassLoader$vmethods	java_security_SecureClassLoader;
};

// Vtype
struct _jc_java_security_SecureClassLoader$vtype {
	_jc_type			type;
	_jc_java_security_SecureClassLoader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_SecureClassLoader$sub_refs {
	struct _jc_java_util_WeakHashMap$object	*protectionDomainCache;
};

// Reference instance fields (object)
struct _jc_java_security_SecureClassLoader$refs {
    _jc_java_security_SecureClassLoader$sub_refs	java_security_SecureClassLoader;
    _jc_java_lang_ClassLoader$sub_refs	java_lang_ClassLoader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_SecureClassLoader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_SecureClassLoader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_ClassLoader$sub_nonrefs	java_lang_ClassLoader;
    _jc_java_security_SecureClassLoader$sub_nonrefs	java_security_SecureClassLoader;
};

// Object instance structure
struct _jc_java_security_SecureClassLoader$object {
	_jc_java_security_SecureClassLoader$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_SecureClassLoader$vtype	*vtype;
	_jc_java_security_SecureClassLoader$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_SecureClassLoader$vtype _jc_java_security_SecureClassLoader$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_SecureClassLoader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_SecureClassLoader$class_object;

#endif	/* _JC_java_security_SecureClassLoader_H_ */

==> jc-1.4.5.tar.gz: java/security/SecureClassLoader.h <==
// public class java.security.SecureClassLoader

// class file dependencies
// @dep_class 58c6b9c5ce1fc756 java_lang_ClassLoader
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 50a05c4401dcb8be java_security_SecureClassLoader

// header file dependencies
// @dep_header java_lang_ClassLoader

#include "java/lang/ClassLoader.h"

#ifndef _JC_java_security_SecureClassLoader_H_
#define _JC_java_security_SecureClassLoader_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_CodeSource$object;
struct _jc_java_security_PermissionCollection$object;
struct _jc_java_util_WeakHashMap$object;

// Typedefs
typedef struct _jc_java_security_SecureClassLoader$sub_refs	_jc_java_security_SecureClassLoader$sub_refs;
typedef struct _jc_java_security_SecureClassLoader$sub_nonrefs	_jc_java_security_SecureClassLoader$sub_nonrefs;
typedef struct _jc_java_security_SecureClassLoader$refs	_jc_java_security_SecureClassLoader$refs;
typedef struct _jc_java_security_SecureClassLoader$nonrefs	_jc_java_security_SecureClassLoader$nonrefs;
typedef struct _jc_java_security_SecureClassLoader$object	_jc_java_security_SecureClassLoader$object;

typedef const struct _jc_java_security_SecureClassLoader$vmethods	_jc_java_security_SecureClassLoader$vmethods;
typedef const struct _jc_java_security_SecureClassLoader$vtable	_jc_java_security_SecureClassLoader$vtable;
typedef const struct _jc_java_security_SecureClassLoader$vtype	_jc_java_security_SecureClassLoader$vtype;

// Constructors
extern void _jc_java_security_SecureClassLoader$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_SecureClassLoader$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_SecureClassLoader$method$_init$2815ca8f2d550897(_jc_env *, struct _jc_java_security_SecureClassLoader$object *, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_java_security_SecureClassLoader$method$defineClass$75df0c3a50185132(_jc_env *, struct _jc_java_security_SecureClassLoader$object *, struct _jc_java_lang_String$object *, struct _jc_byte_array *, jint, jint, struct _jc_java_security_CodeSource$object *) _JC_JCNI_ATTR;
extern struct _jc_java_security_PermissionCollection$object *_jc_java_security_SecureClassLoader$method$getPermissions$448009107719f384(_jc_env *, struct _jc_java_security_SecureClassLoader$object *, struct _jc_java_security_CodeSource$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_SecureClassLoader$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_SecureClassLoader$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_SecureClassLoader$method_info$defineClass$75df0c3a50185132;
extern _jc_method _jc_java_security_SecureClassLoader$method_info$getPermissions$448009107719f384;
extern _jc_method _jc_java_security_SecureClassLoader$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_security_SecureClassLoader$vmethods {
	struct _jc_java_lang_Class$object	*(*defineClass$75df0c3a50185132)(_jc_env *, struct _jc_java_security_SecureClassLoader$object *, struct _jc_java_lang_String$object *, struct _jc_byte_array *, jint, jint, struct _jc_java_security_CodeSource$object *) _JC_JCNI_ATTR;
	struct _jc_java_security_PermissionCollection$object	*(*getPermissions$448009107719f384)(_jc_env *, struct _jc_java_security_SecureClassLoader$object *, struct _jc_java_security_CodeSource$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_SecureClassLoader$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_SecureClassLoader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_ClassLoader$vmethods	java_lang_ClassLoader;
	_jc_java_security_SecureClassLoader$vmethods	java_security_SecureClassLoader;
};

// Vtype
struct _jc_java_security_SecureClassLoader$vtype {
	_jc_type			type;
	_jc_java_security_SecureClassLoader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_SecureClassLoader$sub_refs {
	struct _jc_java_util_WeakHashMap$object	*protectionDomainCache;
};

// Reference instance fields (object)
struct _jc_java_security_SecureClassLoader$refs {
    _jc_java_security_SecureClassLoader$sub_refs	java_security_SecureClassLoader;
    _jc_java_lang_ClassLoader$sub_refs	java_lang_ClassLoader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_SecureClassLoader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_SecureClassLoader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_ClassLoader$sub_nonrefs	java_lang_ClassLoader;
    _jc_java_security_SecureClassLoader$sub_nonrefs	java_security_SecureClassLoader;
};

// Object instance structure
struct _jc_java_security_SecureClassLoader$object {
	_jc_java_security_SecureClassLoader$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_SecureClassLoader$vtype	*vtype;
	_jc_java_security_SecureClassLoader$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_SecureClassLoader$vtype _jc_java_security_SecureClassLoader$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_SecureClassLoader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_SecureClassLoader$class_object;

#endif	/* _JC_java_security_SecureClassLoader_H_ */
